==> chaosmesh-model-5.2.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/IoChaosBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class IoChaosBuilder extends IoChaosFluentImpl<IoChaosBuilder> implements VisitableBuilder<IoChaos,IoChaosBuilder> {

    IoChaosFluent<?> fluent;
    Boolean validationEnabled;

    public IoChaosBuilder() {
        this(true);
    }

    public IoChaosBuilder(Boolean validationEnabled) {
        this(new IoChaos(), validationEnabled);
    }

    public IoChaosBuilder(IoChaosFluent<?> fluent) {
        this(fluent, true);
    }

    public IoChaosBuilder(IoChaosFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new IoChaos(), validationEnabled);
    }

    public IoChaosBuilder(IoChaosFluent<?> fluent,IoChaos instance) {
        this(fluent, instance, true);
    }

    public IoChaosBuilder(IoChaosFluent<?> fluent,IoChaos instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public IoChaosBuilder(IoChaos instance) {
        this(instance,true);
    }

    public IoChaosBuilder(IoChaos instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.chaosmesh.v1alpha1.EditableIoChaos build() {
        EditableIoChaos buildable = new EditableIoChaos(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        IoChaosBuilder that = (IoChaosBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> chaosmesh-model-5.3.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/IoChaosBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class IoChaosBuilder extends IoChaosFluentImpl<IoChaosBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<IoChaos,IoChaosBuilder> {

    IoChaosFluent<?> fluent;
    Boolean validationEnabled;

    public IoChaosBuilder() {
        this(true);
    }

    public IoChaosBuilder(Boolean validationEnabled) {
        this(new IoChaos(), validationEnabled);
    }

    public IoChaosBuilder(IoChaosFluent<?> fluent) {
        this(fluent, true);
    }

    public IoChaosBuilder(IoChaosFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new IoChaos(), validationEnabled);
    }

    public IoChaosBuilder(IoChaosFluent<?> fluent,IoChaos instance) {
        this(fluent, instance, true);
    }

    public IoChaosBuilder(IoChaosFluent<?> fluent,IoChaos instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public IoChaosBuilder(IoChaos instance) {
        this(instance,true);
    }

    public IoChaosBuilder(IoChaos instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.chaosmesh.v1alpha1.EditableIoChaos build() {
        EditableIoChaos buildable = new EditableIoChaos(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        IoChaosBuilder that = (IoChaosBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
